==> haskell-ghc-exactprint-1.7.1.0-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-exactprint
version:              1.7.1.0
visibility:           public
id:                   ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
key:                  ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.6.*. For earlier GHC
    versions see lower version numbers.

category:             Development
abi:                  f9cc168af7a58029ab9e6b8f9badbded
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-exactprint-1.7.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-exactprint-1.7.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-exactprint-1.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-3fckYVSYEwRA3sQVkSQiQV ghc-9.6.6
    ghc-boot-9.6.6 mtl-2.3.1
    ordered-containers-0.2.4-EwHJBRsxryDGW0prEJhSCp
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-exactprint-1.7.1.0-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-exactprint
version:              1.7.1.0
visibility:           public
id:                   ghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9
key:                  ghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.6.*. For earlier GHC
    versions see lower version numbers.

category:             Development
abi:                  702cadc9c0700d59635b39777e0c0e37
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-exactprint-1.7.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-exactprint-1.7.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-exactprint-1.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-CP2SAI6deNWCXG1eD5QmMc ghc-9.6.6
    ghc-boot-9.6.6 mtl-2.3.1
    ordered-containers-0.2.4-7LS72pannWi66bkfz7GPiT
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
